==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/uk/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Користувач скасував запит на об\'єкт на веб-сайті',
    'a_user_requested' => 'Користувач надіслав запит на об\'єкт на веб-сайті',
    'accessory_name' => 'Назва аксесуара:',
    'additional_notes' => 'Додаткові примітки:',
    'admin_has_created' => 'Адміністратор створив вам обліковий запис на веб-сайті.',
    'asset' => 'Актив:',
    'asset_name' => 'Найменування Активу:',
    'asset_requested' => 'Запит на актив',
    'asset_tag' => 'Тег активу:',
    'assigned_to' => 'Відповідальний',
    'best_regards' => 'З найкращими побажаннями,',
    'canceled' => 'Скасовано:',
    'checkin_date' => 'Дата повернення:',
    'checkout_date' => 'Дата видачі:',
    'click_to_confirm' => 'Будь-ласка, натисніть на це посилання, щоб підтвердити свій: веб-акаунт:',
    'click_on_the_link_accessory' => 'Будь ласка, натисніть на посилання внизу, щоб підтвердити, що Ви отримали аксесуар.',
    'click_on_the_link_asset' => 'Будь ласка, натисніть на посилання внизу, щоб підтвердити, що Ви отримали актив.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Поточна к-ксть',
    'Days' => 'Днів',
    'days' => 'Днів',
    'expecting_checkin_date' => 'Очікувана дата повернення:',
    'expires' => 'Термін закінчується',
    'Expiring_Assets_Report' => 'Звіт про активи з завершенням терміну придатності.',
    'Expiring_Licenses_Report' => 'Звіт про ліцензії з завершеням терміну придатності.',
    'hello' => 'Привіт',
    'hi' => 'Привіт',
    'i_have_read' => 'Я прочитав і згоден з умовами використання даного товару.',
    'item' => 'Елемент:',
    'Item_Request_Canceled' => 'Запит скасовано',
    'Item_Requested' => 'Запит на',
    'link_to_update_password' => 'Будь-ласка, натисніть на це посилання, щоб оновити свій пароль:',
    'login_first_admin' => 'Login to your new Snipe-IT installation using the credentials below:',
    'login' => 'Логін:',
    'Low_Inventory_Report' => 'Low Inventory Report',
    'min_QTY' => 'Мін. кількість',
    'name' => 'Назва',
    'new_item_checked' => 'Новий елемент був виданий під вашим ім\'ям, докладніше про це нижче.',
    'password' => 'Пароль:',
    'password_reset' => 'Скидання Пароля',

    'read_the_terms' => 'Будь ласка, прочитайте умови використання нижче.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read
                         and agree to the terms of use, and have received the asset.',
    'requested' => 'Запрошено користувачем:',
    'reset_link' => 'Ваше посилання для скидання пароля',
    'reset_password' => 'Натисніть тут для скидання пароля:',
    'serial' => 'Serial',
    'supplier' => 'Постачальник',
    'tag' => 'Тег',
    'test_email' => 'Test Email from Snipe-IT',
    'test_mail_text' => 'This is a test from the Snipe-IT Asset Management System. If you got this, mail is working :)',
    'the_following_item' => 'The following item has been checked in: ',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'To reset your :web password, complete this form:',
    'type' => 'Тип',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Ласкаво просимо, :name',
    'welcome_to' => 'Ласкаво просимо до :web!',
    'your_credentials' => 'Ваші облікові дані Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/uk/mail.php <==
<?php

return [
    'a_user_canceled' => 'Користувач скасував запит на об\'єкт на веб-сайті',
    'a_user_requested' => 'Користувач надіслав запит на об\'єкт на веб-сайті',
    'accessory_name' => 'Назва аксесуара:',
    'additional_notes' => 'Додаткові примітки:',
    'admin_has_created' => 'Адміністратор створив вам обліковий запис на веб-сайті.',
    'asset' => 'Актив:',
    'asset_name' => 'Найменування Активу:',
    'asset_requested' => 'Запит на актив',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Відповідальний',
    'best_regards' => 'З найкращими побажаннями,',
    'canceled' => 'Скасовано:',
    'checkin_date' => 'Дата повернення:',
    'checkout_date' => 'Дата видачі:',
    'click_to_confirm' => 'Будь-ласка, натисніть на це посилання, щоб підтвердити свій: веб-акаунт:',
    'click_on_the_link_accessory' => 'Будь ласка, натисніть на посилання внизу, щоб підтвердити, що Ви отримали аксесуар.',
    'click_on_the_link_asset' => 'Будь ласка, натисніть на посилання внизу, щоб підтвердити, що Ви отримали актив.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Поточна к-ксть',
    'Days' => 'Днів',
    'days' => 'Днів',
    'expecting_checkin_date' => 'Очікувана дата повернення:',
    'expires' => 'Термін закінчується',
    'Expiring_Assets_Report' => 'Звіт про активи з завершенням терміну придатності.',
    'Expiring_Licenses_Report' => 'Звіт про ліцензії з завершеням терміну придатності.',
    'hello' => 'Привіт',
    'hi' => 'Привіт',
    'i_have_read' => 'Я прочитав і згоден з умовами використання даного товару.',
    'item' => 'Елемент:',
    'Item_Request_Canceled' => 'Запит скасовано',
    'Item_Requested' => 'Запит на',
    'link_to_update_password' => 'Будь-ласка, натисніть на це посилання, щоб оновити свій пароль:',
    'login_first_admin' => 'Login to your new Snipe-IT installation using the credentials below:',
    'login' => 'Логін:',
    'Low_Inventory_Report' => 'Low Inventory Report',
    'min_QTY' => 'Мін. кількість',
    'name' => 'Назва',
    'new_item_checked' => 'Новий елемент був виданий під вашим ім\'ям, докладніше про це нижче.',
    'password' => 'Пароль:',
    'password_reset' => 'Скидання Пароля',

    'read_the_terms' => 'Будь ласка, прочитайте умови використання нижче.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read
                         and agree to the terms of use, and have received the asset.',
    'requested' => 'Запрошено користувачем:',
    'reset_link' => 'Ваше посилання для скидання пароля',
    'reset_password' => 'Натисніть тут для скидання пароля:',
    'serial' => 'Serial',
    'supplier' => 'Постачальник',
    'tag' => 'Тег',
    'test_email' => 'Test Email from Snipe-IT',
    'test_mail_text' => 'This is a test from the Snipe-IT Asset Management System. If you got this, mail is working :)',
    'the_following_item' => 'The following item has been checked in: ',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'To reset your :web password, complete this form:',
    'type' => 'Тип',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Ласкаво просимо, :name',
    'welcome_to' => 'Ласкаво просимо до :web!',
    'your_credentials' => 'Ваші облікові дані Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
